==> freecad_0.17%2Bdfsg1.orig.tar.gz: FreeCAD-0.17/src/Mod/Image/Gui/Resources/translations/Image_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Kép sík létrehozása...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Hozzon létre egy síkbeli képet a 3D-s térben</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>hozzon létre egy síkbeli képet a 3D-s térben</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Megnyitás...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Kép megnyitása megtekintése</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>A képnéző által meghatározhatatlan típusú színtér</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Képpont formátum</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Válasszon orientáció</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Kép sík</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-sík</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-sík</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-sík</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Fordított irányban</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Eltolás:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Kép kitöltse a képernyőt</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Nyújtsa ki a képet, hogy illeszkedjen a nézethez</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 léptékű</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>A kép megjelenítése 1:1 méretarányban</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Eredeti szín</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Eredeti színekkel jelenítse meg a képet</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Világosított szín</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Világosított színekkel jelenítse meg a képet</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Szabvány</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Kész ...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>szürke</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>nagyítás</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>külső kép</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Képnéző</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Képek (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="+20"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Egy képfájl kiválasztása megnyitásra</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Képek</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Összes fájl</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Hiba a kép megnyitása során</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nem sikerült betölteni a kiválasztott képet</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Hiba a kép megnyitásakor</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nem sikerült betölteni a kiválasztott képet</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
  </context>
</TS>

==> freecad_0.18~pre1%2Bdfsg1.orig.tar.gz: FreeCAD-0.18_pre/src/Mod/Image/Gui/Resources/translations/Image_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="hu" sourcelanguage="en">
  <context>
    <name>CmdCreateImagePlane</name>
    <message>
      <location filename="../../Command.cpp" line="+101"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create image plane...</source>
      <translation>Kép sík létrehozása...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Create a planar image in the 3D space</source>
      <translation>Hozzon létre egy síkbeli képet a 3D-s térben</translation>
    </message>
    <message>
      <source>create a planar image in the 3D space</source>
      <translation>hozzon létre egy síkbeli képet a 3D-s térben</translation>
    </message>
  </context>
  <context>
    <name>CmdImageOpen</name>
    <message>
      <location line="-50"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open...</source>
      <translation>Megnyitás...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Open image view</source>
      <translation>Kép megnyitása megtekintése</translation>
    </message>
  </context>
  <context>
    <name>CmdImageScaling</name>
    <message>
      <location line="+120"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Scale...</source>
      <translation>Lépték...</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Image Scaling</source>
      <translation>Kép méretezése</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::GLImageBox</name>
    <message>
      <location filename="../../GLImageBox.cpp" line="+333"/>
      <location filename="../../OpenGLImageBox.cpp" line="+385"/>
      <source>Undefined type of colour space for image viewing</source>
      <translation>A képnéző által meghatározhatatlan típusú színtér</translation>
    </message>
    <message>
      <location line="-1"/>
      <location filename="../../OpenGLImageBox.cpp" line="-1"/>
      <source>Image pixel format</source>
      <translation>Képpont formátum</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageOrientationDialog</name>
    <message>
      <location filename="../../ImageOrientationDialog.ui" line="+14"/>
      <source>Choose orientation</source>
      <translation>Válasszon orientáció</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>Image plane</source>
      <translation>Kép sík</translation>
    </message>
    <message>
      <location line="+6"/>
      <source>XY-Plane</source>
      <translation>XY-sík</translation>
    </message>
    <message>
      <location line="+10"/>
      <source>XZ-Plane</source>
      <translation>XZ-sík</translation>
    </message>
    <message>
      <location line="+7"/>
      <source>YZ-Plane</source>
      <translation>YZ-sík</translation>
    </message>
    <message>
      <location line="+29"/>
      <source>Reverse direction</source>
      <translation>Fordított irányban</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Offset:</source>
      <translation>Eltolás:</translation>
    </message>
  </context>
  <context>
    <name>ImageGui::ImageView</name>
    <message>
      <location filename="../../ImageView.cpp" line="+107"/>
      <source>&amp;Fit image</source>
      <translation>Kép kitöltse a képernyőt</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Stretch the image to fit the view</source>
      <translation>Nyújtsa ki a képet, hogy illeszkedjen a nézethez</translation>
    </message>
    <message>
      <location line="+4"/>
      <source>&amp;1:1 scale</source>
      <translation>&amp;1:1 léptékű</translation>
    </message>
    <message>
      <location line="+2"/>
      <source>Display the image at a 1:1 scale</source>
      <translation>A kép megjelenítése 1:1 méretarányban</translation>
    </message>
    <message>
      <source>&amp;Original color</source>
      <translation>&amp;Eredeti szín</translation>
    </message>
    <message>
      <source>Display the image with its original color(s)</source>
      <translation>Eredeti színekkel jelenítse meg a képet</translation>
    </message>
    <message>
      <source>&amp;Brightened color</source>
      <translation>&amp;Világosított szín</translation>
    </message>
    <message>
      <source>Display the image with brightened color(s)</source>
      <translation>Világosított színekkel jelenítse meg a képet</translation>
    </message>
    <message>
      <location line="+9"/>
      <source>Standard</source>
      <translation>Szabvány</translation>
    </message>
    <message>
      <location line="+18"/>
      <source>Ready...</source>
      <translation>Kész ...</translation>
    </message>
    <message>
      <location line="+390"/>
      <source>grey</source>
      <translation>szürke</translation>
    </message>
    <message>
      <location line="+1"/>
      <location line="+3"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+10"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <location line="+11"/>
      <location line="+5"/>
      <source>zoom</source>
      <translation>nagyítás</translation>
    </message>
    <message>
      <location line="-62"/>
      <location line="+10"/>
      <location line="+15"/>
      <location line="+16"/>
      <location line="+16"/>
      <source>outside image</source>
      <translation>külső kép</translation>
    </message>
  </context>
  <context>
    <name>QObject</name>
    <message>
      <source>Image viewer</source>
      <translation>Képnéző</translation>
    </message>
    <message>
      <source>Images (*.png *.xpm *.jpg *.bmp)</source>
      <translation>Képek (*.png *.xpm *.jpg *.bmp)</translation>
    </message>
    <message>
      <location filename="../../Command.cpp" line="-102"/>
      <location line="+47"/>
      <source>Choose an image file to open</source>
      <translation>Egy képfájl kiválasztása megnyitásra</translation>
    </message>
    <message>
      <location line="-54"/>
      <location line="+47"/>
      <source>Images</source>
      <translation>Képek</translation>
    </message>
    <message>
      <location line="-42"/>
      <location line="+47"/>
      <source>All files</source>
      <translation>Összes fájl</translation>
    </message>
    <message>
      <location line="+8"/>
      <source>Error opening image</source>
      <translation>Hiba a kép megnyitása során</translation>
    </message>
    <message>
      <location line="+1"/>
      <source>Could not load the chosen image</source>
      <translation>Nem sikerült betölteni a kiválasztott képet</translation>
    </message>
    <message>
      <source>Error open image</source>
      <translation>Hiba a kép megnyitásakor</translation>
    </message>
    <message>
      <source>Could not load the choosen image</source>
      <translation>Nem sikerült betölteni a kiválasztott képet</translation>
    </message>
  </context>
  <context>
    <name>Workbench</name>
    <message>
      <location filename="../../Workbench.cpp" line="+36"/>
      <source>Image</source>
      <translation>Kép</translation>
    </message>
  </context>
</TS>
